==> momosimplebbs-0.1.3.zip: momosimplebbs-0.1.3/src/momosimplebbs.inc.php <==
<?php
require_once("common.php");

/**
 * ɽ
 */
function viewLogs($num) {
    global $logDirName, $logFileName, $maxKensu, $isViewIP;
    if (is_null($num) || !is_numeric($num)) {
        $num = 0;
    }

    if (!file_exists($logDirName . "/" . $logFileName)) {
        print "(ޤ)";
    }
    else {
        $logFile = $logDirName . "/" . $logFileName;
        $lines = file($logFile);
	
        if (count($lines) == 0) {
            print "(ޤ)";
        }
        else {
            // ɤ߹
            $lines = array_reverse($lines);
            $arr = array_chunk($lines, $maxKensu);
            for ($ii = 0; $ii < count($arr[$num]); $ii++) {
                list($date, $ip, $title, $name, $message) = explode("<>", $arr[$num][$ii]);
                print '<span class="title">' . $title  . '</span><br>' . "\n";
                print "̾$name ";
                print "$date ";
                if ($isViewIP) {
                    print "IP$ip";
                }
                print "<br>\n";
                print "$message<br>\n";

                if ($ii < count($arr[$num]) - 1) {
                    print "<hr>\n";
                }
            }
        }
    }
    
}

/**
 * åɽ뤿ֹΥ
 */
function viewLogNumber($num) {
    global $logDirName, $logFileName, $maxKensu;
    if (is_null($num) || !is_numeric($num)) {
        $num = 0;
    }

    if (file_exists($logDirName . "/" . $logFileName)) {
        $logFile = $logDirName . "/" . $logFileName;
        $lines = file($logFile);
	
        if (count($lines) == 0 || (count($lines) / $maxKensu) == 0
            || ((floor(count($lines) / $maxKensu) == 1) && (count($lines) % $maxKensu) == 0)) {
            // ⤷ʤ
        }
        else {
            $divide = floor(count($lines) / $maxKensu);
            $amari = count($lines) % $maxKensu;

            if ($divide > 0 && $amari > 0) {
                $count = $divide + 1;
            }
            else if ($divide > 0 && $amari == 0) {
                $count = $divide;
            }

            for ($ii = 0; $ii < $count; $ii++) {
                if ($ii == $num) {
                    print '<b>' . ($ii + 1) . '</b>' . "\n";
                }
                else{
                    print '<a href="index.php?num=' . $ii . '">';
                    print $ii + 1;
                    print "</a>\n";
                }
            }
        }
    }
}

/**
 * ǼĤΥեåʬɽ
 */
function viewFooter() {
    global $bbsName, $bbsVer, $isViewBBSVer;

    print $bbsName . "<br>\n";
    if ($isViewBBSVer) {
        print '<a href="http://momoutils.sourceforge.jp/">momo simple BBS</a> version '. $bbsVer . "<br>\n";
        print '<a href="http://momoutils.sourceforge.jp/">momoUtils</a><br>' . "\n";
    }
}

/**
 * åե˽񤭹
 *
 * @return 1֤񤭹ʤäfalse֤
 */
function writeMessage($title, $name, $date, $ip, $message)
{
    global $logDirName, $logFileName;

    $title = eregi_replace("\r\n", "", htmlspecialchars($title, ENT_QUOTES));
    $title = eregi_replace("\n", "", $title);
    $name = eregi_replace("\r\n", "", htmlspecialchars($name, ENT_QUOTES));
    $name = eregi_replace("\n", "", $name);
    $date = eregi_replace("\r\n", "", htmlspecialchars($date, ENT_QUOTES));
    $date = eregi_replace("\n", "", $date);
    $ip = eregi_replace("\r\n", "", htmlspecialchars($ip, ENT_QUOTES));
    $ip = eregi_replace("\n", "", $ip);
    $message = eregi_replace("\r\n", "<br>", htmlspecialchars($message, ENT_QUOTES));
    $message = eregi_replace("\n", "<br>", $message);
    
    $input = "$date<>$ip<>$title<>$name<>$message\n";
    if (!$fp = fopen($logDirName . "/" . $logFileName, 'a')) {
        echo "$logDirName/$logFileNameޤ";
        return false;
    }

    if (!lockDir($logFileName)) {
        echo "Ƥޤ\n";
        return false;
    }
    
    if (fwrite($fp, $input) == false) {
        echo "$logDirName/$logFileName˽񤭹ޤ";
        return false;
    }

    unlockDir($logFileName);

    fclose($fp);

    return 1;
}

/**
 * ǥ쥯ȥѤåԤ<br>
 * åβˤunlockDirؿȤȡ
 * @param $file åե̾
 * @param int $retry Ե(ÿ)<br>
 *        ǥեȤ3á
 * @param string $lockdir åѥǥ쥯ȥ֤ǥ쥯ȥꡣ<br>
 *        ǥեȤ"_lock"
 * @return åǤȤtrueʤäȤfalse֤
 */
function lockDir($file,  $retry = 3, $lockdir = "_lock") {
    $lockfile = $lockdir . "/" . $file;

    // 30ðʾвᤷå
    if (file_exists($lockfile)) {
        $mtime = filemtime($lockfile);
        if ($mtime < time() -30) {
            unlockDir($file);
        }
    }

    // åѥǥ쥯ȥ
    while (!@mkdir($lockfile, 0755)) {
        if ($retry-- <= 0) {
            return false;
        }
        sleep(1);
    }

    return true;
}

/**
 * ǥ쥯ȥѤå(lockDirؿѤå)βԤ<br>
 * å򤹤ˤlockDirؿȤȡ
 * @param $file åե̾
 * @param string $lockdir åѥǥ쥯ȥ֤ǥ쥯ȥꡣ<br>
 *        ǥեȤ"_lock"
 */
function unlockDir($file, $lockdir = "_lock") {
    $lockfile = $lockdir . "/" . $file;

    if (file_exists($lockfile)) {
        rmdir($lockfile);
    }
}

/**
 * ֥饦˥å夵ʤHTTPإåꡣ
 * δؿHTML򵭽Ҥ˼¹Ԥɬפ롣
 *
 * @param $charset ʸɤꤹ롣ꤷʤShift_JISˤʤ롣
 */
function printNoCacheHeader($charset = "Shift_JIS") {
    header("Content-Type: text/html; charset=" . $charset);
    header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
    header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
    header("Cache-Control: no-store, no-cache, must-revalidate");
    header("Cache-Control: post-check=0, pre-check=0", false);
    header("Pragma: no-cache");
}

?>

==> momosimplebbs-0.1.4.zip: momosimplebbs-0.1.4/src/momosimplebbs.inc.php <==
<?php
/**
 * @author    S.Isogai
 * @copyright 2007 momoutils project
 * @license   http://www.apache.org/licenses/LICENSE-2.0  Apache License 2.0
 * @link      http://momoutils.sourceforge.jp/
 */
require_once("common.php");

/**
 * ɽ
 */
function viewLogs($num) {
    global $logDirName, $logFileName, $maxKensu, $isViewIP;
    if (is_null($num) || !is_numeric($num)) {
        $num = 0;
    }

    if (!file_exists($logDirName . "/" . $logFileName)) {
        print "(ޤ)";
    }
    else {
        $logFile = $logDirName . "/" . $logFileName;
        $lines = file($logFile);
	
        if (count($lines) == 0) {
            print "(ޤ)";
        }
        else {
            // ɤ߹
            $lines = array_reverse($lines);
            $arr = array_chunk($lines, $maxKensu);
            for ($ii = 0; $ii < count($arr[$num]); $ii++) {
                list($date, $ip, $title, $name, $message) = explode("<>", $arr[$num][$ii]);
                print '<span class="title">' . $title  . '</span><br>' . "\n";
                print "̾$name ";
                print "$date ";
                if ($isViewIP) {
                    print "IP$ip";
                }
                print "<br>\n";
                print "$message<br>\n";

                if ($ii < count($arr[$num]) - 1) {
                    print "<hr>\n";
                }
            }
        }
    }
    
}

/**
 * åɽ뤿ֹΥ
 */
function viewLogNumber($num) {
    global $logDirName, $logFileName, $maxKensu;
    if (is_null($num) || !is_numeric($num)) {
        $num = 0;
    }

    if (file_exists($logDirName . "/" . $logFileName)) {
        $logFile = $logDirName . "/" . $logFileName;
        $lines = file($logFile);
	
        if (count($lines) == 0 || (count($lines) / $maxKensu) == 0
            || ((floor(count($lines) / $maxKensu) == 1) && (count($lines) % $maxKensu) == 0)) {
            // ⤷ʤ
        }
        else {
            $divide = floor(count($lines) / $maxKensu);
            $amari = count($lines) % $maxKensu;

            if ($divide > 0 && $amari > 0) {
                $count = $divide + 1;
            }
            else if ($divide > 0 && $amari == 0) {
                $count = $divide;
            }

            for ($ii = 0; $ii < $count; $ii++) {
                if ($ii == $num) {
                    print '<b>' . ($ii + 1) . '</b>' . "\n";
                }
                else{
                    print '<a href="index.php?num=' . $ii . '">';
                    print $ii + 1;
                    print "</a>\n";
                }
            }
        }
    }
}

/**
 * ǼĤΥեåʬɽ
 */
function viewFooter() {
    global $bbsName, $bbsVer, $isViewBBSVer;

    print $bbsName . "<br>\n";
    if ($isViewBBSVer) {
        print '<a href="http://momoutils.sourceforge.jp/">momo simple BBS</a> version '. $bbsVer . "<br>\n";
        print '<a href="http://momoutils.sourceforge.jp/">momoUtils</a><br>' . "\n";
    }
}

/**
 * åե˽񤭹
 *
 * @return true֤񤭹ʤäϥ饹Error֤
 */
function writeMessage($messageData)
{
    global $logDirName, $logFileName;

    $err = new Error();

    $messageData->sanitizingHtmlTagAll();
    $messageData->replaceLineFeedAll();
    
    $input = $messageData->toLogString();

    if (!file_exists($logDirName) && !is_dir($logDirName)) {
        $err->add("ǥ쥯ȥ".$logDirName."¸ߤޤ");
        return $err;
    }
    
    if (!$fp = fopen($logDirName . "/" . $logFileName, 'a')) {
        $err->add("$logDirName/$logFileNameޤ");
        return $err;
    }

    if (!lockDir($logFileName)) {
        $err->add("ƤޤΤǡäƤޤƤƲ");
        return $err;
    }
    
    if (fwrite($fp, $input) == false) {
        $err->add("$logDirName/$logFileName˽񤭹ޤ");
        return $err;
    }

    unlockDir($logFileName);

    fclose($fp);

    return true;
}

function validateMessage(&$messageData) {
    global $maxTitleLength, $maxNameLength, $maxMessageLength, $maxMessageLine;

    $messageData->setValidateRule($maxNameLength, $maxTitleLength, $maxMessageLength, $maxMessageLine);
    return $messageData->validate();
}


/**
 * ǥ쥯ȥѤåԤ<br>
 * åβˤunlockDirؿȤȡ
 * @param $file åե̾
 * @param int $retry Ե(ÿ)<br>
 *        ǥեȤ3á
 * @param string $lockdir åѥǥ쥯ȥ֤ǥ쥯ȥꡣ<br>
 *        ǥեȤ"_lock"
 * @return åǤȤtrueʤäȤfalse֤
 */
function lockDir($file,  $retry = 3, $lockdir = "_lock") {
    $lockfile = $lockdir . "/" . $file;

    // 30ðʾвᤷå
    if (file_exists($lockfile)) {
        $mtime = filemtime($lockfile);
        if ($mtime < time() -30) {
            unlockDir($file);
        }
    }

    // åѥǥ쥯ȥ
    while (!@mkdir($lockfile, 0755)) {
        if ($retry-- <= 0) {
            return false;
        }
        sleep(1);
    }

    return true;
}

/**
 * ǥ쥯ȥѤå(lockDirؿѤå)βԤ<br>
 * å򤹤ˤlockDirؿȤȡ
 * @param $file åե̾
 * @param string $lockdir åѥǥ쥯ȥ֤ǥ쥯ȥꡣ<br>
 *        ǥեȤ"_lock"
 */
function unlockDir($file, $lockdir = "_lock") {
    $lockfile = $lockdir . "/" . $file;

    if (file_exists($lockfile)) {
        rmdir($lockfile);
    }
}

/**
 * 饹ErrorΥ顼åɽ롣
 */
function viewError($err) {
    $err->header = '<font color="red">';
    $err->footer = '</font>' . "\n";
    $err->separator = '<br>' . "\n";

    $err->showAllMessages();
}


/**
 * ֥饦˥å夵ʤHTTPإåꡣ
 * δؿHTML򵭽Ҥ˼¹Ԥɬפ롣
 *
 * @param $charset ʸɤꤹ롣ꤷʤShift_JISˤʤ롣
 */
function printNoCacheHeader($charset = "Shift_JIS") {
    header("Content-Type: text/html; charset=" . $charset);
    header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
    header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
    header("Cache-Control: no-store, no-cache, must-revalidate");
    header("Cache-Control: post-check=0, pre-check=0", false);
    header("Pragma: no-cache");
}

?>
